package de.hdm_stuttgart.mi.sda1.saxhtml.v2;

import java.io.IOException;
import java.io.PrintStream;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParser;
import javax.xml.parsers.SAXParserFactory;

import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;

import de.hdm_stuttgart.mi.sda1.saxhtml.v1.MyErrorHandler;

/** Parser, content- and error handler assembly */
public class Memo2Html {

	private final XMLReader xmlReader;
	private final Memo2HtmlHandler eventHandler;
	private final MyErrorHandler errorHandler = new MyErrorHandler();

	/**
	 * @param out Write output to stream
	 * @throws SAXException
	 *             Parsing may fail.
	 * @throws ParserConfigurationException
	 *             Unable to instantiate parser.
	 */
	public Memo2Html(final PrintStream out) throws SAXException,
			ParserConfigurationException {
		final SAXParserFactory saxPf = SAXParserFactory.newInstance();
		final SAXParser saxParser = saxPf.newSAXParser();
		xmlReader = saxParser.getXMLReader();

		eventHandler = new Memo2HtmlHandler(out);
		xmlReader.setContentHandler(eventHandler);
		xmlReader.setErrorHandler(errorHandler);
	}

	/**
	 * Parse an existing memo instance and create HTML output.
	 * 
	 * @param uri
	 *            The resource to be parsed
	 * @throws IOException
	 *             Access related problems
	 * @throws SAXException
	 *             Parsing may fail
	 */
	public void parse(final String uri) throws IOException, SAXException {
		xmlReader.parse(uri);
	}
}