package de.hdm_stuttgart.mi.sda1.saxhtml.v2;

import java.io.PrintStream;
import java.util.List;
import java.util.Vector;

import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Turning &lt;memo&gt; documents to HTML
 *
 */
public class Memo2HtmlHandler extends DefaultHandler {

	private final PrintStream out;

	/**
	 * @param out
	 *            Write output to stream
	 */
	public Memo2HtmlHandler(final PrintStream out) {
		this.out = out;
	}

	String from, subject, content;
	final List<String> recipients = new Vector<String>();
	final StringBuffer buffer = new StringBuffer();

	@Override
	public void startDocument() throws SAXException {
		// Clear
		recipients.clear();
	}

	@Override
	public void startElement(String uri, String localName, String tagName,
			Attributes attributes) throws SAXException {
		buffer.setLength(0); // Clear string buffer
	}

	@Override
	public void characters(char[] ch, int start, int length)
			throws SAXException {
		buffer.append(ch, start, length);
	}

	@Override
	public void endElement(String uri, String localName, String tagName)
			throws SAXException {
		switch (tagName) {

		case "from":
			from = buffer.toString();
			break;

		case "to":
			recipients.add(buffer.toString());
			break;

		case "subject":
			subject = buffer.toString();
			break;

		case "content":
			content = buffer.toString();
			break;
		}
	}

	@Override
	public void endDocument() throws SAXException {
		// First portion until sender
		out.print("<html>\n" // xmlns='http://www.w3.org/1999/xhtml'
				+ "  <head><title>Memo from " + from
				+ "</title></head>\n"
				+ "  <body>\n" + "    <h2>Subject:" + subject
				+ "</h2>\n"
				+ "    <dl>\n" + "      <dt>Sender:</dt>\n"
				+ "      <dd>"
				+ from + "</dd>\n"
				+ "      <dt>Recipients:</dt>\n"
				+ "      <dd>\n" + "        <ul>\n");

		// Recipients
		for (final String recipient : recipients) {
			out.print("          <li>" + recipient + "</li>\n");
		}
		// Tail including reference to sender
		out.print("        </ul>\n" + "      </dd>\n" + "    </dl>\n"
				+ "    <h2>Subject: " + subject + "</h2>\n" + "    <p>"
				+ content + "</p>\n" + "    <p>End of message from <strong>"
				+ from + "</strong></p>\n" + "  </body>\n" + "</html>\n");
		out.flush();
	}
}