package de.hdm_stuttgart.de.sda1.saxhtml.v1.test;

import java.io.IOException;
import java.io.PrintStream;

import javax.xml.parsers.ParserConfigurationException;

import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;
import org.junit.BeforeClass;
import org.junit.Test;
import org.xml.sax.SAXException;

import de.hdm_stuttgart.de.testing.dom.DomAssert;
import de.hdm_stuttgart.mi.sda1.saxhtml.v1.Memo2Html;

/**
 * Unit testing XML to HTML output
 */
@SuppressWarnings("javadoc")
public class ConversionTest {
   
   final static String
      xmlInputFileName = "src/main/resources/memo.xml",
      htmlOutputFileName = xmlInputFileName + ".1.html";
   
   static Element htmlRootElement; 
   
   @BeforeClass public static void init()
         throws JDOMException, SAXException, ParserConfigurationException, IOException {
      
         final PrintStream out = new PrintStream(htmlOutputFileName);
         final Memo2Html memo2html = new Memo2Html(out);
         memo2html.parse(xmlInputFileName);
         final SAXBuilder parser = new SAXBuilder();
         htmlRootElement = parser.build(htmlOutputFileName).getRootElement();
         out.close();
   }
   
   @Test public void testSenderInHeader() {
      DomAssert.assertSingleNodeContent("<title>Memo message</title> must be the only child of <head>", htmlRootElement, "head/*", "title", "Memo message");
   }
   @Test public void testFrom() {
      DomAssert.assertSingleNodeContent("<strong>M. Goik</strong> must appear within first <h2> child of <body>",
            htmlRootElement, "body/h2[1]/strong", "strong", "M. Goik");
   }
   @Test public void testNumberfRecipients() {
      DomAssert.assertNumberOfNodes("Two <li> elements required matching two recipients", htmlRootElement, "body/ul/li", 2);
   }
   @Test public void testSecondRecipient() {
      DomAssert.assertSingleNodeContent("Second recipient must be <li>A. June</li>",
            htmlRootElement, "body/ul/li[2]", "li", "A. June");
   }
   @Test public void testSubject() {
      DomAssert.assertSingleNodeContent("<h2>Subject: Best wishes</h2> must appear as first child of <body>",
            htmlRootElement, "body/*[4]", "h2", "Subject: Best wishes");
   }
   @Test public void testContent() {
      DomAssert.assertSingleNodeContent("Last child of <body> must be content",
            htmlRootElement, "body/*[5]", "p", "Hi all, congratulations to your splendid party");
   }
}