package de.hdm_stuttgart.de.sda1.saxhtml.v2.test;

import java.io.IOException;
import java.io.PrintStream;

import javax.xml.parsers.ParserConfigurationException;

import org.jdom2.Element;
import org.jdom2.JDOMException;
import org.jdom2.input.SAXBuilder;
import org.junit.BeforeClass;
import org.junit.Test;
import org.xml.sax.SAXException;

import de.hdm_stuttgart.de.testing.dom.DomAssert;
import de.hdm_stuttgart.mi.sda1.saxhtml.v2.Memo2Html;

/**
 * Turning &lt;memo&gt; documents to HTML as being shown in sample document memo.xml.2.sample.html 

 */
@SuppressWarnings("javadoc")
public class ConversionTest {

	final static String
	xmlInputFileName = "src/main/resources/memo.xml",
	htmlOutputFileName = xmlInputFileName + ".2.html";

	static Element htmlRootElement; 

	/**
	 * @throws JDOMException
	 * @throws SAXException
	 * @throws ParserConfigurationException
	 * @throws IOException
	 */
	@BeforeClass public static void init()
			throws JDOMException, SAXException, ParserConfigurationException, IOException {

		final PrintStream out = new PrintStream(htmlOutputFileName);
		final Memo2Html memo2html = new Memo2Html(out);
		memo2html.parse(xmlInputFileName);
		final SAXBuilder parser = new SAXBuilder();
		htmlRootElement = parser.build(htmlOutputFileName).getRootElement();
		out.close();
	}

	@Test public void testSenderInHeader() {
		DomAssert.assertSingleNodeContent("<title>Memo from M. Goik</title> must be child of <head>", htmlRootElement, "head/title", "Memo from M. Goik");
	}
	@Test public void testNumberfRecipients() {
		DomAssert.assertNumberOfNodes("There should be two <li> elements matching two recipients", htmlRootElement, "body/dl/dd/ul/li", 2);
	}
	@Test public void testH1MemoSubjectMessage() {
		DomAssert.assertSingleNodeContent("<h2>Subject:Best wishes</h2> must appear as first child of <body>",
				htmlRootElement, "body/*[1]", "h2", "Subject:Best wishes");
	}
	@Test public void testSenderBeforeRecipientList() {
		DomAssert.assertSingleNodeContent("<dd>M. Goik</dd> must appear as second child  of the list of recipients",
				htmlRootElement, "body/dl/*[2]", "dd", "M. Goik");
	}
	@Test public void testMemoContent() {
		DomAssert.assertSingleNodeContent("content must appear as second <p> child after recipient list in <body>",
				htmlRootElement, "body/dl/following-sibling::*[2]", "p", "Hi all, congratulations to your splendid party");
	}
	@Test public void testLastParagraph() {
		DomAssert.assertNumberOfNodes("Expecting two <p> children of <body>",
				htmlRootElement, "body/*[name(.)='p']", 2);
	}
	@Test public void testSenderAtFoot() {
		DomAssert.assertSingleNodeContent("<strong>M. Goik</strong> must appear inside a <p> immediately following the list of recipients",
				htmlRootElement, "body/dl/following-sibling::*[1]", "h2", "Subject: Best wishes");
	}
}